"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RequestHandler = exports.logger = void 0;
const winston_1 = require("winston");
/**
 * The mapping of the possible log level names to their corresponding level
 */
const logLevels = {
    fatal: 0,
    error: 1,
    warn: 2,
    info: 3,
    debug: 4,
    trace: 5,
};
exports.logger = (0, winston_1.createLogger)({
    format: winston_1.format.json(),
    exitOnError: false,
    levels: logLevels,
    transports: [
        new winston_1.transports.Console({ level: 'debug' }),
    ],
});
class RequestHandler {
    constructor(functionName) {
        this.log = (level, message, meta) => {
            const logEntry = {
                level: level,
                message: message,
                requestId: this.id,
                currentFunction: this.currentFunctionName,
                ...meta
            };
            this.logEntries.push(logEntry);
        };
        this.id = RequestHandler.currentIndex++;
        this.currentFunctionName = functionName;
        this.logEntries = [];
    }
    executeSync(f, ...args) {
        this.log('debug', `Entering sync function "${f.name}"`, { input: args });
        const previousFunctionName = this.currentFunctionName;
        this.currentFunctionName = f.name;
        const result = f(this, ...args);
        this.currentFunctionName = previousFunctionName;
        this.log('debug', `Leaving sync function "${f.name}"`, { output: result });
        return result;
    }
    async executeAsync(f, ...args) {
        this.log('debug', `Entering async function "${f.name}"`, { input: args });
        const previousFunctionName = this.currentFunctionName;
        this.currentFunctionName = f.name;
        const result = await f(this, ...args);
        this.currentFunctionName = previousFunctionName;
        this.log('debug', `Leaving async function "${f.name}"`, { output: result });
        return result;
    }
    throw(error, ...args) {
        const err = new error(...args);
        const status = err.status;
        delete err.status;
        RequestHandler.logger.log('error', `${err.name} ${status}: "${err.message}"`, { error: err.stack, status, trace: this.logEntries });
        throw { ...err, status };
    }
}
exports.RequestHandler = RequestHandler;
RequestHandler.currentIndex = 0;
RequestHandler.logger = exports.logger;
//# sourceMappingURL=requestHandler.js.map